==> james-project-3.7.6-source-release.zip: james-project/server/container/guice/common/src/main/java/org/apache/james/GuiceLifecycleHealthCheck.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james;

import javax.inject.Inject;

import org.apache.james.core.healthcheck.ComponentName;
import org.apache.james.core.healthcheck.HealthCheck;
import org.apache.james.core.healthcheck.Result;

import reactor.core.publisher.Mono;

public class GuiceLifecycleHealthCheck implements HealthCheck {
    private final IsStartedProbe probe;

    @Inject
    public GuiceLifecycleHealthCheck(IsStartedProbe probe) {
        this.probe = probe;
    }

    @Override
    public ComponentName componentName() {
        return new ComponentName("Guice application lifecycle");
    }

    @Override
    public Mono<Result> check() {
        if (probe.isStarted()) {
            return Mono.just(Result.healthy(componentName()));
        } else {
            return Mono.just(Result.unhealthy(componentName(), "James server is not started."));
        }
    }
}

==> james-project-3.9.0-source-release.zip: james-project/server/container/guice/common/src/main/java/org/apache/james/GuiceLifecycleHealthCheck.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james;

import jakarta.inject.Inject;

import org.apache.james.core.healthcheck.ComponentName;
import org.apache.james.core.healthcheck.HealthCheck;
import org.apache.james.core.healthcheck.Result;

import reactor.core.publisher.Mono;

public class GuiceLifecycleHealthCheck implements HealthCheck {
    private final IsStartedProbe probe;

    @Inject
    public GuiceLifecycleHealthCheck(IsStartedProbe probe) {
        this.probe = probe;
    }

    @Override
    public ComponentName componentName() {
        return new ComponentName("Guice application lifecycle");
    }

    @Override
    public Mono<Result> check() {
        if (probe.isStarted()) {
            return Mono.just(Result.healthy(componentName()));
        } else {
            return Mono.just(Result.unhealthy(componentName(), "James server is not started."));
        }
    }
}
